@@ -12,7 +12,8 @@
          " \n",
          "Huang Z, Han Z, Wang T, Shao W, Xiang S, Salama P, Rizkalla M, Huang K, Zhang J.\n",
          "TSUNAMI: Translational Bioinformatics Tool Suite For Network Analysis And Mining.\n",
-         "bioRxiv. 2019 Jan 1:787507.\n"))
+         "Genomics, Proteomics & Bioinformatics, Volume 19, Issue 6, December 2021, Pages 1023-1031\n",
+         "https://doi.org/10.1016/j.gpb.2019.05.006."))
   packageStartupMessage("==========================================================================\n\n");
 }
 
